summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/gui/opengl/opengl.pri7
-rw-r--r--src/opengl/opengl.pro8
-rw-r--r--src/opengl/qopenglqueryhelper_p.h (renamed from src/gui/opengl/qopenglqueryhelper_p.h)2
-rw-r--r--src/opengl/qopengltimerquery.cpp (renamed from src/gui/opengl/qopengltimerquery.cpp)6
-rw-r--r--src/opengl/qopengltimerquery.h (renamed from src/gui/opengl/qopengltimerquery.h)8
5 files changed, 18 insertions, 13 deletions
diff --git a/src/gui/opengl/opengl.pri b/src/gui/opengl/opengl.pri
index 9eab55f112..26060ea5df 100644
--- a/src/gui/opengl/opengl.pri
+++ b/src/gui/opengl/opengl.pri
@@ -85,9 +85,7 @@ qtConfig(opengl) {
opengl/qopenglfunctions_4_2_compatibility.h \
opengl/qopenglfunctions_4_3_compatibility.h \
opengl/qopenglfunctions_4_4_compatibility.h \
- opengl/qopenglfunctions_4_5_compatibility.h \
- opengl/qopenglqueryhelper_p.h \
- opengl/qopengltimerquery.h
+ opengl/qopenglfunctions_4_5_compatibility.h
SOURCES += opengl/qopenglfunctions_1_0.cpp \
opengl/qopenglfunctions_1_1.cpp \
@@ -114,8 +112,7 @@ qtConfig(opengl) {
opengl/qopenglfunctions_4_2_compatibility.cpp \
opengl/qopenglfunctions_4_3_compatibility.cpp \
opengl/qopenglfunctions_4_4_compatibility.cpp \
- opengl/qopenglfunctions_4_5_compatibility.cpp \
- opengl/qopengltimerquery.cpp
+ opengl/qopenglfunctions_4_5_compatibility.cpp
}
qtConfig(opengles2) {
diff --git a/src/opengl/opengl.pro b/src/opengl/opengl.pro
index b9d0c6213d..820e46ed79 100644
--- a/src/opengl/opengl.pro
+++ b/src/opengl/opengl.pro
@@ -15,4 +15,12 @@ HEADERS += \
SOURCES += \
qopengldebug.cpp
+!qtConfig(opengles2) {
+ HEADERS += \
+ qopenglqueryhelper_p.h \
+ qopengltimerquery.h
+
+ SOURCES += qopengltimerquery.cpp
+}
+
load(qt_module)
diff --git a/src/gui/opengl/qopenglqueryhelper_p.h b/src/opengl/qopenglqueryhelper_p.h
index ad91ca9f96..f3ed997f98 100644
--- a/src/gui/opengl/qopenglqueryhelper_p.h
+++ b/src/opengl/qopenglqueryhelper_p.h
@@ -3,7 +3,7 @@
** Copyright (C) 2013 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtGui module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
diff --git a/src/gui/opengl/qopengltimerquery.h b/src/opengl/qopengltimerquery.h
index 27da74a3fb..a779240108 100644
--- a/src/gui/opengl/qopengltimerquery.h
+++ b/src/opengl/qopengltimerquery.h
@@ -3,7 +3,7 @@
** Copyright (C) 2013 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtGui module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -40,7 +40,7 @@
#ifndef QOPENGLTIMERQUERY_H
#define QOPENGLTIMERQUERY_H
-#include <QtGui/qtguiglobal.h>
+#include <QtOpenGL/qtopenglglobal.h>
#if !defined(QT_NO_OPENGL) && !defined(QT_OPENGL_ES_2)
@@ -51,7 +51,7 @@ QT_BEGIN_NAMESPACE
class QOpenGLTimerQueryPrivate;
-class Q_GUI_EXPORT QOpenGLTimerQuery : public QObject
+class Q_OPENGL_EXPORT QOpenGLTimerQuery : public QObject
{
Q_OBJECT
@@ -79,7 +79,7 @@ private:
class QOpenGLTimeMonitorPrivate;
-class Q_GUI_EXPORT QOpenGLTimeMonitor : public QObject
+class Q_OPENGL_EXPORT QOpenGLTimeMonitor : public QObject
{
Q_OBJECT
diff --git a/src/gui/opengl/qopengltimerquery.cpp b/src/opengl/qopengltimerquery.cpp
index a4e10b42f7..44955d48fc 100644
--- a/src/gui/opengl/qopengltimerquery.cpp
+++ b/src/opengl/qopengltimerquery.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2013 Klaralvdalens Datakonsult AB (KDAB).
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtGui module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
@@ -238,7 +238,7 @@ GLuint64 QOpenGLTimerQueryPrivate::result() const
/*!
\class QOpenGLTimerQuery
\brief The QOpenGLTimerQuery class wraps an OpenGL timer query object.
- \inmodule QtGui
+ \inmodule QtOpenGL
\since 5.1
\ingroup painting-3D
@@ -645,7 +645,7 @@ void QOpenGLTimeMonitorPrivate::reset()
/*!
\class QOpenGLTimeMonitor
\brief The QOpenGLTimeMonitor class wraps a sequence of OpenGL timer query objects.
- \inmodule QtGui
+ \inmodule QtOpenGL
\since 5.1
\ingroup painting-3D
@@ -3,7 +3,7 @@
** Contact: https://www.qt.io/licensing/
**
-** This file is part of the QtGui module of the Qt Toolkit.
+** This file is part of the QtOpenGL module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$